@@ -56,7 +56,7 @@ module A = struct (* Additional AST construction helpers *)
 
   let mod_ ~loc : (string -> structure -> structure_item) =
     fun name structure ->
-      pstr_module ~loc (module_binding ~loc ~name:(Located.mk ~loc name)
+      pstr_module ~loc (module_binding ~loc ~name:(Located.mk ~loc (Some name))
                           ~expr:(pmod_structure ~loc structure))
 
   let sig_item ~loc name typ =
@@ -66,7 +66,7 @@ module A = struct (* Additional AST construction helpers *)
 
   let sig_mod ~loc : (string -> signature -> signature_item) =
     fun name signature ->
-      psig_module ~loc (module_declaration ~loc ~name:(Located.mk ~loc name)
+      psig_module ~loc (module_declaration ~loc ~name:(Located.mk ~loc (Some name))
                           ~type_:(pmty_signature ~loc signature))
 
 end
